# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-03-12 11:18
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('marketplace', '0061_rename_resource_count'),
    ]

    operations = [
        migrations.AddField(
            model_name='aggregateresourcecount',
            name='content_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='contenttypes.ContentType'),
        ),
        migrations.AddField(
            model_name='aggregateresourcecount',
            name='object_id',
            field=models.PositiveIntegerField(null=True),
        ),
    ]
